unit U_capt;

interface

uses WinTypes, WinProcs, Classes, Graphics, Forms, Controls, Buttons,
  StdCtrls, ExtCtrls, SysUtils,
  CALMIS16, CALPRT16, CALBND16, 
  Delphi_U, U_Vars;

type
  TDlgCaptureSettings = class(TForm)
    OKBtn: TBitBtn;
    CancelBtn: TBitBtn;
    HelpBtn: TBitBtn;
    Bevel1: TBevel;
    RadioGroupPorts: TRadioGroup;
    GroupBoxCaptureSettings: TGroupBox;
    EditDesc: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    EditTabSize: TEdit;
    EditCopies: TEdit;
    EditForm: TEdit;
    EditBanner: TEdit;
    EditTimeout: TEdit;
    EditQueue: TEdit;
    RadioGroupPortStatus: TRadioGroup;
    ButtonChange: TButton;
    Label4: TLabel;
    ButtonFlush: TButton;
    procedure FormActivate(Sender: TObject);
    procedure RadioGroupPortsClick(Sender: TObject);
    procedure GetCaptureStatusAndFlags(Sender: TObject);
    procedure EditDescChange(Sender: TObject);
    procedure EditBannerChange(Sender: TObject);
    procedure SettingsChanged(Sender: TObject; NewValue: Boolean);
    procedure EditCopiesChange(Sender: TObject);
    procedure EditTabSizeChange(Sender: TObject);
    procedure EditTimeoutChange(Sender: TObject);
    procedure ButtonChangeClick(Sender: TObject);
    procedure EditFormChange(Sender: TObject);
    procedure EditQueueExit(Sender: TObject);
    procedure RadioGroupPortStatusExit(Sender: TObject);
    procedure ButtonFlushClick(Sender: TObject);
  private
    { Private declarations }
    LPTDevice     : nuint8;
    Changed       : boolean;
    captureFlags1 : NWCAPTURE_FLAGS1;
    captureFlags2 : NWCAPTURE_FLAGS2;
    code          : Integer;
    status        : Integer;
  public
    { Public declarations }
  end;

var
  DlgCaptureSettings: TDlgCaptureSettings;

implementation

{$R *.DFM}

procedure TDlgCaptureSettings.FormActivate(Sender: TObject);
begin
   RadioGroupPorts.ItemIndex := 0;
   Changed                   := False;
end;

procedure TDlgCaptureSettings.RadioGroupPortsClick(Sender: TObject);
begin
   LPTDevice := Succ(RadioGroupPorts.ItemIndex);
   GetCaptureStatusAndFlags(Sender);
end;

procedure TDlgCaptureSettings.GetCaptureStatusAndFlags(Sender: TObject);
begin
   EditDesc.Text    := '';
   EditTabSize.Text := '';
   EditCopies.Text  := '';
   EditForm.Text    := '';
   EditBanner.Text  := '';
   EditTimeout.Text := '';
   EditQueue.Text   := '';

   FillChar(captureFlags1, SizeOf(captureFlags1), 0);
   FillChar(captureFlags2, SizeOf(captureFlags2), 0);
   cCode := NWGetCaptureFlags(LPTDevice, captureFlags1, captureFlags2);

   Case cCode of
     $0:    status := 0;
     $8801: status := 1;
     else   status := 2;
     end;

   RadioGroupPortStatus.ItemIndex := status;
   ButtonFlush.Enabled            := (status=0);

   if (cCode = 0) then begin
      EditDesc.Text    := StrPas(@captureFlags1.jobDesciption);
      EditTabSize.Text := IntToStr(captureFlags1.tabSize);
      EditCopies.Text  := IntToStr(captureFlags1.numCopies);
      EditForm.Text    := IntToStr(captureFlags1.formType) + ' ' + StrPas(@captureFlags1.formName);
      EditBanner.Text  := StrPas(@captureFlags1.bannerText);
      EditTimeout.Text := IntToStr(captureFlags1.flushCaptureTimeout);
      EditQueue.Text   := StrPas(@captureFlags2.queueName);
      end;
   SettingsChanged(Sender, FALSE);
end;

procedure TDlgCaptureSettings.EditFormChange(Sender: TObject);
begin
   SettingsChanged(Sender, TRUE);
   Val(EditForm.Text, captureFlags1.formType, code);
end;

procedure TDlgCaptureSettings.EditCopiesChange(Sender: TObject);
begin
   SettingsChanged(Sender, TRUE);
   Val(EditCopies.Text, captureFlags1.numCopies, code);
end;

procedure TDlgCaptureSettings.EditTabSizeChange(Sender: TObject);
begin
   SettingsChanged(Sender, TRUE);
   Val(EditTabSize.Text, captureFlags1.tabSize, code);
end;

procedure TDlgCaptureSettings.EditTimeoutChange(Sender: TObject);
begin
   SettingsChanged(Sender, TRUE);
   Val(EditTimeout.Text, captureFlags1.flushCaptureTimeout, code);
end;

procedure TDlgCaptureSettings.EditDescChange(Sender: TObject);
begin
   SettingsChanged(Sender, TRUE);
   StrPCopy(@captureFlags1.jobDesciption, EditDesc.Text);
end;

procedure TDlgCaptureSettings.EditBannerChange(Sender: TObject);
begin
   SettingsChanged(Sender, TRUE);
   StrPCopy(@captureFlags1.bannerText, EditBanner.Text);
end;

procedure TDlgCaptureSettings.SettingsChanged(Sender: TObject; NewValue: Boolean);
begin
   Changed := NewValue;
   ButtonChange.Enabled := NewValue;
end;

procedure TDlgCaptureSettings.ButtonChangeClick(Sender: TObject);
begin
   cCode := NWSetCaptureFlags(connHandle, LPTDevice, captureFlags1);
   ErrorMessage(cCode, 'NWSetCaptureFlags');
   GetCaptureStatusAndFlags(Sender);
end;

procedure TDlgCaptureSettings.EditQueueExit(Sender: TObject);
VAR
   objID   : nuint32;
   objName : String;
begin { capture to new queue ? }
   objName := EditQueue.Text;
   if objName <> StrPas(@captureFlags2.queueName) then begin
      cCode := GetObjIDFromName(objID, OT_PRINT_QUEUE, objName);
      ErrorMessage(cCode, 'GetObjIDFromName');
      if (cCode=0) then begin
         TerminateString(objName);
         cCode := NWStartQueueCapture(connHandle, LPTDevice, objID, @objName[1]);
         ErrorMessage(cCode, 'NWStartQueueCapture');
         GetCaptureStatusAndFlags(Sender);
         end;

      end;
end;

procedure TDlgCaptureSettings.RadioGroupPortStatusExit(Sender: TObject);
begin  { change capture status ? }
   if RadioGroupPortStatus.ItemIndex <> status then
      begin
      if (status = 2) or (RadioGroupPortStatus.ItemIndex=2)
         then begin
              MyShowMessage('The printer can only be en-/disabled in NET.CFG');
              RadioGroupPortStatus.ItemIndex := status;
              end
         else case RadioGroupPortStatus.ItemIndex of
                0: begin
                   MyShowMessage('Start capturing by entering a valid queue name');
                   RadioGroupPortStatus.ItemIndex := status;
                   end;
                1: begin
                   cCode := NWEndCapture(LPTDevice);
                   ErrorMessage(cCode, 'NWEndCapture');
                   GetCaptureStatusAndFlags(Sender);
                   end;
                end;
      end;
end;

procedure TDlgCaptureSettings.ButtonFlushClick(Sender: TObject);
begin
   cCode := NWFlushCapture(LPTDevice);
   ErrorMessage(cCode, 'NWFlushCapture');
end;

end.
